@@ -1894,9 +1894,10 @@ static int read_idrisi32_point_data(DATA *d, const char *fname) {
             read(fb,n_points2,4);
             read(fb, tmp, 256);
 			*/
-			fread(tmp, 1, 1, f);
-			fread(n_points2, 4, 1, f);
-			fread(tmp, 256, 1, f);
+			if (fread(tmp, 1, 1, f) != 1 ||
+				fread(n_points2, 4, 1, f) != 1 ||
+				fread(tmp, 256, 1, f) != 1)
+					ErrMsg(ER_READ, fname);
 
             efree(n_points2); 
 			efree(tmp);
@@ -1904,7 +1905,8 @@ static int read_idrisi32_point_data(DATA *d, const char *fname) {
 
             if (total < 65520) {
             	/* KS: read(fb,vecptr,total); */
-				fread(vecptr, (unsigned int) total, 1, f);
+				if (fread(vecptr, (unsigned int) total, 1, f) != 1)
+					ErrMsg(ER_READ, fname);
             	total = (int)(total/8);
             	i = 0;
     			while (i < total) {
